@@ -1,4 +1,4 @@
-__version__ = '1.0.26'
+__version__ = '1.0.28'
 __author__ = 'arnold'
 
 import json
@@ -117,7 +117,8 @@ class TerraformQueryExtension(Extension):
             if(output["attributes"]["name"] == name):
                 if((value_name is not None) and (output["attributes"]["value"][value_name] is not None)):
                     return output["attributes"]["value"][value_name]
-                elif(output["attributes"]["value"] is not None):
+                elif((len(output["attributes"]["value"])!=0)):
+                    print(len(output["attributes"]["value"]))
                     return output["attributes"]["value"]
                 else:
                     sys.exit("Value is None for attribute " +name)
